imblearn.under_sampling.RandomUnderSampler
==========================================

.. currentmodule:: imblearn.under_sampling

.. autoclass:: RandomUnderSampler

   
   .. automethod:: __init__

   
   .. rubric:: Methods

   .. autosummary::
   
      ~RandomUnderSampler.__init__
      ~RandomUnderSampler.fit
      ~RandomUnderSampler.fit_sample
      ~RandomUnderSampler.get_params
      ~RandomUnderSampler.sample
      ~RandomUnderSampler.set_params
   
   

   
   
   